<?php
namespace XLite\View\Tabs;
/**
 * Tabs related to user profile section
 *
 * @ListChild (list="admin.center", zone="admin")
 */
class AdminProfile extends \XLite\Module\QSL\BraintreeVZ\View\Tabs\AdminProfile {}